.\"" SPDX-License-Identifier: MIT
.Sh SPECIAL THANKS
To all who support further development, in particular:
.Bl -bullet -compact -offset indent -width "@"
.It
ThePhD
.It
Embark Studios
.It
Lars Strojny
.It
EvModder
.El
.
.Sh REPORTING BUGS
.Lk https://todo.sr.ht/~nabijaczleweli/febug "febug tracker"
.Pp
febug mailing list:
.Aq Mt ~nabijaczleweli/febug@lists.sr.ht ,
archived at
.Lk https://lists.sr.ht/~nabijaczleweli/febug
